0.9.9 API documentation: Matrix types

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Typedefs
Matrix types
Core features

Matrix types of with C columns and R rows where C and R are values between 2 to 4 included. More...

## Typedefs
typedef mat< 2, 2, double, defaultp > | dmat2
| 2 columns of 2 components matrix of double-precision floating-point numbers. More...
typedef mat< 2, 2, double, defaultp > | dmat2x2
| 2 columns of 2 components matrix of double-precision floating-point numbers. More...
typedef mat< 2, 3, double, defaultp > | dmat2x3
| 2 columns of 3 components matrix of double-precision floating-point numbers. More...
typedef mat< 2, 4, double, defaultp > | dmat2x4
| 2 columns of 4 components matrix of double-precision floating-point numbers. More...
typedef mat< 3, 3, double, defaultp > | dmat3
| 3 columns of 3 components matrix of double-precision floating-point numbers. More...
typedef mat< 3, 2, double, defaultp > | dmat3x2
| 3 columns of 2 components matrix of double-precision floating-point numbers. More...
typedef mat< 3, 3, double, defaultp > | dmat3x3
| 3 columns of 3 components matrix of double-precision floating-point numbers. More...
typedef mat< 3, 4, double, defaultp > | dmat3x4
| 3 columns of 4 components matrix of double-precision floating-point numbers. More...
typedef mat< 4, 4, double, defaultp > | dmat4
| 4 columns of 4 components matrix of double-precision floating-point numbers. More...
typedef mat< 4, 2, double, defaultp > | dmat4x2
| 4 columns of 2 components matrix of double-precision floating-point numbers. More...
typedef mat< 4, 3, double, defaultp > | dmat4x3
| 4 columns of 3 components matrix of double-precision floating-point numbers. More...
typedef mat< 4, 4, double, defaultp > | dmat4x4
| 4 columns of 4 components matrix of double-precision floating-point numbers. More...
typedef mat< 2, 2, float, defaultp > | mat2
| 2 columns of 2 components matrix of single-precision floating-point numbers. More...
typedef mat< 2, 2, float, defaultp > | mat2x2
| 2 columns of 2 components matrix of single-precision floating-point numbers. More...
typedef mat< 2, 3, float, defaultp > | mat2x3
| 2 columns of 3 components matrix of single-precision floating-point numbers. More...
typedef mat< 2, 4, float, defaultp > | mat2x4
| 2 columns of 4 components matrix of single-precision floating-point numbers. More...
typedef mat< 3, 3, float, defaultp > | mat3
| 3 columns of 3 components matrix of single-precision floating-point numbers. More...
typedef mat< 3, 3, float, defaultp > | mat3x3
| 3 columns of 3 components matrix of single-precision floating-point numbers. More...
typedef mat< 3, 4, float, defaultp > | mat3x4
| 3 columns of 4 components matrix of single-precision floating-point numbers. More...
typedef mat< 4, 2, float, defaultp > | mat4x2
| 4 columns of 2 components matrix of single-precision floating-point numbers. More...
typedef mat< 4, 3, float, defaultp > | mat4x3
| 4 columns of 3 components matrix of single-precision floating-point numbers. More...
typedef mat< 4, 4, float, defaultp > | mat4x4
| 4 columns of 4 components matrix of single-precision floating-point numbers. More...
typedef mat< 4, 4, float, defaultp > | mat4
| 4 columns of 4 components matrix of single-precision floating-point numbers. More...

## Detailed Description

Matrix types of with C columns and R rows where C and R are values between 2 to 4 included.

These types have exhaustive sets of operators.

## Typedef Documentation

typedef mat< 2, 2, f64, defaultp > dmat2

2 columns of 2 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 20 of file matrix_double2x2.hpp.

typedef mat< 2, 2, double, defaultp > dmat2x2

2 columns of 2 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double2x2.hpp.

typedef mat< 2, 3, double, defaultp > dmat2x3

2 columns of 3 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double2x3.hpp.

typedef mat< 2, 4, double, defaultp > dmat2x4

2 columns of 4 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double2x4.hpp.

typedef mat< 3, 3, f64, defaultp > dmat3

3 columns of 3 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 20 of file matrix_double3x3.hpp.

typedef mat< 3, 2, double, defaultp > dmat3x2

3 columns of 2 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double3x2.hpp.

typedef mat< 3, 3, double, defaultp > dmat3x3

3 columns of 3 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double3x3.hpp.

typedef mat< 3, 4, double, defaultp > dmat3x4

3 columns of 4 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double3x4.hpp.

typedef mat< 4, 4, f64, defaultp > dmat4

4 columns of 4 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 20 of file matrix_double4x4.hpp.

typedef mat< 4, 2, double, defaultp > dmat4x2

4 columns of 2 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double4x2.hpp.

typedef mat< 4, 3, double, defaultp > dmat4x3

4 columns of 3 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double4x3.hpp.

typedef mat< 4, 4, double, defaultp > dmat4x4

4 columns of 4 components matrix of double-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_double4x4.hpp.

typedef mat< 2, 2, f32, defaultp > mat2

2 columns of 2 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 20 of file matrix_float2x2.hpp.

typedef mat< 2, 2, f32, defaultp > mat2x2

2 columns of 2 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float2x2.hpp.

typedef mat< 2, 3, f32, defaultp > mat2x3

2 columns of 3 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float2x3.hpp.

typedef mat< 2, 4, f32, defaultp > mat2x4

2 columns of 4 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float2x4.hpp.

typedef mat< 3, 3, f32, defaultp > mat3

3 columns of 3 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 20 of file matrix_float3x3.hpp.

typedef mat< 3, 3, f32, defaultp > mat3x3

3 columns of 3 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float3x3.hpp.

typedef mat< 3, 4, f32, defaultp > mat3x4

3 columns of 4 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float3x4.hpp.

typedef mat< 4, 4, f32, defaultp > mat4

4 columns of 4 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 20 of file matrix_float4x4.hpp.

typedef mat< 4, 2, f32, defaultp > mat4x2

4 columns of 2 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float4x2.hpp.

typedef mat< 4, 3, f32, defaultp > mat4x3

4 columns of 3 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float4x3.hpp.

typedef mat< 4, 4, f32, defaultp > mat4x4

4 columns of 4 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float4x4.hpp.